summaryrefslogtreecommitdiffstats
path: root/libkdepim/sidebarextension.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/sidebarextension.h')
-rw-r--r--libkdepim/sidebarextension.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libkdepim/sidebarextension.h b/libkdepim/sidebarextension.h
index b1f6bccd..e65d3c94 100644
--- a/libkdepim/sidebarextension.h
+++ b/libkdepim/sidebarextension.h
@@ -21,7 +21,7 @@
#ifndef SIDEBAREXTENSION_H
#define SIDEBAREXTENSION_H
-#include <qobject.h>
+#include <tqobject.h>
#include <kdepimmacros.h>
class QWidget;
@@ -43,21 +43,21 @@ namespace KParts
/**
* Constucts a SideBarExtension.
*
* @param exported A QWidget derived widget that will be provided for the
* users of SideBarExtension.
* @param parent The parent widget.
* @param name The name of the class.
**/
- SideBarExtension(QWidget *exported, KParts::ReadOnlyPart *parent, const char* name);
+ SideBarExtension(TQWidget *exported, KParts::ReadOnlyPart *parent, const char* name);
~SideBarExtension();
/**
* Retrieve a pointer to the widget. May be 0 if 0 was passed in the constructor
**/
- QWidget* widget() const { return m_exported; }
+ TQWidget* widget() const { return m_exported; }
private:
- QWidget* m_exported;
+ TQWidget* m_exported;
class SideBarExtensionPrivate;
SideBarExtensionPrivate *d;
@@ -43,21 +43,21 @@ namespace KParts
* Constucts a SideBarExtension.
*
- * @param exported A QWidget derived widget that will be provided for the
+ * @param exported A TQWidget derived widget that will be provided for the
* users of SideBarExtension.
* @param parent The parent widget.